@@ -8,6 +8,18 @@ pub struct RequestRecord {
     pub timestamp: DateTime<Utc>,
 }
 
+impl From<RequestRecord> for String {
+    fn from(r: RequestRecord) -> Self {
+        format!(
+            "timestamp='{:?}',latency='{:?}',status='{}',body='{}'",
+            r.timestamp.timestamp(),
+            r.latency.num_nanoseconds(),
+            r.response_code,
+            r.response_body
+        )
+    }
+}
+
 impl RequestRecord {
     pub fn new(latency: Duration, response_code: u16, response_body: String) -> RequestRecord {
         RequestRecord {
@@ -17,14 +29,4 @@ impl RequestRecord {
             timestamp: Utc::now(),
         }
     }
-
-    pub fn to_csv_string(&self) -> String {
-        format!(
-            "timestamp='{:?}',latency='{:?}',status='{}',body='{}'",
-            self.timestamp.timestamp(),
-            self.latency.num_nanoseconds(),
-            self.response_code,
-            self.response_body
-        )
-    }
 }
